@@ -1,10 +1,4 @@
-book.stack <-
-function(A,B,k=2,alpha=0.05,bit=FALSE){
-# A includes data  
-# B is the length of words (B-bit) that the chippered file will be divided
-# k is the number of subsets that the alphabet will be divided. length(A)/k tam sayi olacak sekilde bir k secilmelidir
-# alpha is the predetermined value of type-t error.
-# if bit is TRUE a sequence of bits (0,1) of length n will be entered. 
+book.stack=function(A,B,k=2,alpha=0.05,bit=FALSE){
   
   if (bit==TRUE){
     x=A
@@ -17,16 +11,16 @@ function(A,B,k=2,alpha=0.05,bit=FALSE){
 	  bsl=seq(1,N,B)
 	  A=matrix(0,(M-1),1)
 	  for (i in 1:(M-1)){
-		  A[i]=sum(2 ^ (which(as.logical(rev(x[bsl[i]:bitis[i]]))) - 1)) #iki tabanindan on tabanina donusturuyor
-	  }
+		  A[i]=sum(2 ^ (which(as.logical(rev(x[bsl[i]:bitis[i]]))) - 1))
+      }
   }
   
 	alfabe=sum(2 ^ (which(as.logical(rev(matrix(0,B,1)))) - 1)):sum(2 ^ (which(as.logical(rev(matrix(1,B,1)))) - 1)) 
 	M=length(alfabe)
 
-	AA=matrix(0,k,round(M/k))  
-  boluntule=split(alfabe, ceiling(seq_along(alfabe)/round(M/k)))
-	for (i in 1:k){ #length(A)/k tam sayi olacak sekilde bir k secilmelidir.
+	AA=matrix(0,k,round(M/k))
+    boluntule=split(alfabe, ceiling(seq_along(alfabe)/round(M/k)))
+	for (i in 1:k){
 	  AA[i,]=boluntule[[i]]
 	}
   	
@@ -37,7 +31,7 @@ function(A,B,k=2,alpha=0.05,bit=FALSE){
   for (i in 2:nn){
     nu[i,1]=A[i-1]
     AB=nu[(i-1),]
-    nu[i,2:(M+1)]= AB[which(AB!=A[i-1])] #A dizisindeki ilk eleman kacinci sirada ise onun sira numarasi basa gececek digerleri bir kayacak    
+    nu[i,2:(M+1)]= AB[which(AB!=A[i-1])]  
     for (j in 1:k){
       if (sum(AA[j,]==which(nu[(i-1),]==A[(i-1)]))==1){
         n[j]=n[j]+1
@@ -54,11 +48,11 @@ function(A,B,k=2,alpha=0.05,bit=FALSE){
 	pDegeri=1-pchisq(kiKare,(k-1))
   
 	if (pDegeri<alpha){
-		sonucKR=0#H0 ret
+		sonucKR=0
 	} else{
 		sonucKR=1
 	}  
   
 	result=list(statistic=kiKare,p.value=pDegeri,BS.result=sonucKR)
 	return(result)
-}
+}
\ No newline at end of file
